@@ -1,13 +1,13 @@
+import pytest
+import os
+from fastapi.encoders import jsonable_encoder
 from learning_loop_node.context import Context
-from learning_loop_node.trainer.downloader_factory import DownloaderFactory
 from learning_loop_node.annotation_node.data_classes import AnnotationData, EventType, Point, UserInput, EventType
 from learning_loop_node.annotation_node.annotation_node import AnnotationNode
 from learning_loop_node.annotation_node.annotation_tool import EmptyAnnotationTool
-import pytest
-from fastapi.encoders import jsonable_encoder
-from icecream import ic
 from learning_loop_node.model_information import Category, CategoryType
-import os
+from learning_loop_node.rest.downloader import DataDownloader
+from icecream import ic
 
 
 def default_user_input() -> UserInput:
@@ -16,18 +16,12 @@ def default_user_input() -> UserInput:
         event_type=EventType.MouseDown,
         context=Context(organization='zauberzeug', project='pytest'),
         image_uuid='285a92db-bc64-240d-50c2-3212d3973566',
-        category = Category(id='some_id', name = 'category_1', description='', hotkey='', color = '', type=CategoryType.Segmentation)
+        category=Category(id='some_id', name='category_1', description='',
+                          hotkey='', color='', type=CategoryType.Segmentation)
     )
     return UserInput(frontend_id='some_id', data=annotation_data)
 
 
-async def download_basic_data():
-    downloader = DownloaderFactory.create(Context(organization='zauberzeug', project='pytest'))
-    basic_data = await downloader.download_basic_data()
-    image_id = basic_data.image_ids[0]
-    ic(image_id)
-
-
 @pytest.mark.asyncio
 async def test_image_download(create_project):
     image_path = '/tmp/learning_loop_lib_data/zauberzeug/pytest/images/285a92db-bc64-240d-50c2-3212d3973566.jpg'
@@ -36,6 +30,6 @@ async def test_image_download(create_project):
 
     node = AnnotationNode(name="", uuid="", tool=EmptyAnnotationTool())
     input = default_user_input()
-    _ = await node.handle_user_input('zauberzeug', 'pytest', jsonable_encoder(input))
+    _ = await node.handle_user_input(jsonable_encoder(input))
 
     assert os.path.exists(image_path) == True
